@@ -36,7 +36,7 @@ static void code_pair_fetch_i(MVMThreadContext *tc, MVMObject *cont, MVMRegister
 }
 
 static void code_pair_fetch_u(MVMThreadContext *tc, MVMObject *cont, MVMRegister *res) {
-    code_pair_fetch_internal(tc, cont, res, MVM_RETURN_INT);
+    code_pair_fetch_internal(tc, cont, res, MVM_RETURN_UINT);
 }
 
 static void code_pair_fetch_n(MVMThreadContext *tc, MVMObject *cont, MVMRegister *res) {
@@ -114,7 +114,7 @@ static const MVMContainerSpec code_pair_spec = {
     code_pair_fetch_s,
     code_pair_store,
     code_pair_store_i,
-    code_pair_store_i, /* FIXME need a code_pair_store_u but lacking tests showing this need */
+    (void *)code_pair_store_i, /* FIXME need a code_pair_store_u but lacking tests showing this need */
     code_pair_store_n,
     code_pair_store_s,
     code_pair_store,
@@ -141,7 +141,7 @@ static void code_pair_set_container_spec(MVMThreadContext *tc, MVMSTable *st) {
 
 static void code_pair_configure_container_spec(MVMThreadContext *tc, MVMSTable *st, MVMObject *config) {
     CodePairContData *data = (CodePairContData *)st->container_data;
-    MVMROOT2(tc, config, st, {
+    MVMROOT2(tc, config, st) {
         MVMString *fetch = MVM_string_ascii_decode_nt(tc, tc->instance->VMString, "fetch");
 
         if (!MVM_repr_exists_key(tc, config, fetch))
@@ -159,7 +159,7 @@ static void code_pair_configure_container_spec(MVMThreadContext *tc, MVMSTable *
         if (!MVM_code_iscode(tc, store_code))
             MVM_exception_throw_adhoc(tc, "Container spec 'code_pair' must be configured with a code handle");
         MVM_ASSIGN_REF(tc, &(st->header), data->store_code, store_code);
-    });
+    }
 }
 
 static MVMContainerConfigurer CodePairContainerConfigurer = {
@@ -241,25 +241,25 @@ static void value_desc_cont_store(MVMThreadContext *tc, MVMObject *cont, MVMObje
 
 static void value_desc_cont_store_i(MVMThreadContext *tc, MVMObject *cont, MVMint64 value) {
     MVMObject *boxed;
-    MVMROOT(tc, cont, {
+    MVMROOT(tc, cont) {
         boxed = MVM_repr_box_int(tc, MVM_hll_current(tc)->int_box_type, value);
-    });
+    }
     value_desc_cont_store(tc, cont, boxed);
 }
 
 static void value_desc_cont_store_n(MVMThreadContext *tc, MVMObject *cont, MVMnum64 value) {
     MVMObject *boxed;
-    MVMROOT(tc, cont, {
+    MVMROOT(tc, cont) {
         boxed = MVM_repr_box_num(tc, MVM_hll_current(tc)->num_box_type, value);
-    });
+    }
     value_desc_cont_store(tc, cont, boxed);
 }
 
 static void value_desc_cont_store_s(MVMThreadContext *tc, MVMObject *cont, MVMString *value) {
     MVMObject *boxed;
-    MVMROOT(tc, cont, {
+    MVMROOT(tc, cont) {
         boxed = MVM_repr_box_str(tc, MVM_hll_current(tc)->str_box_type, value);
-    });
+    }
     value_desc_cont_store(tc, cont, boxed);
 }
 
@@ -371,7 +371,7 @@ static const MVMContainerSpec value_desc_cont_spec = {
     value_desc_cont_fetch_s,
     value_desc_cont_store,
     value_desc_cont_store_i,
-    value_desc_cont_store_i, /* FIXME need a value_desc_cont_store_u but lacking tests showing this need */
+    (void *)value_desc_cont_store_i, /* FIXME need a value_desc_cont_store_u but lacking tests showing this need */
     value_desc_cont_store_n,
     value_desc_cont_store_s,
     value_desc_cont_store_unchecked,
@@ -398,16 +398,16 @@ static void value_desc_cont_set_container_spec(MVMThreadContext *tc, MVMSTable *
 
 static MVMObject * grab_one_value(MVMThreadContext *tc, MVMObject *config, const char *key) {
     MVMString *key_str;
-    MVMROOT(tc, config, {
+    MVMROOT(tc, config) {
         key_str = MVM_string_ascii_decode_nt(tc, tc->instance->VMString, key);
-    });
+    }
     if (!MVM_repr_exists_key(tc, config, key_str))
         MVM_exception_throw_adhoc(tc, "Container spec must be configured with a '%s'", key);
     return MVM_repr_at_key_o(tc, config, key_str);
 }
 static void value_desc_cont_configure_container_spec(MVMThreadContext *tc, MVMSTable *st, MVMObject *config) {
     MVMValueDescContainer *data = (MVMValueDescContainer *)st->container_data;
-    MVMROOT2(tc, st, config, {
+    MVMROOT2(tc, st, config) {
         MVMObject *value;
         value = grab_one_value(tc, config, "store");
         if (!MVM_code_iscode(tc, value))
@@ -431,7 +431,7 @@ static void value_desc_cont_configure_container_spec(MVMThreadContext *tc, MVMST
         MVM_ASSIGN_REF(tc, &(st->header), data->value_attr, MVM_repr_get_str(tc, value));
         value = grab_one_value(tc, config, "descriptor_attr");
         MVM_ASSIGN_REF(tc, &(st->header), data->descriptor_attr, MVM_repr_get_str(tc, value));
-    });
+    }
     calculate_attr_offsets(tc, st, data);
 }
 
@@ -592,7 +592,7 @@ static void native_ref_store_u(MVMThreadContext *tc, MVMObject *cont, MVMuint64
         MVM_exception_throw_adhoc(tc, "This container does not reference a native integer");
     switch (repr_data->ref_kind) {
         case MVM_NATIVEREF_LEX:
-            MVM_nativeref_write_lex_i(tc, cont, value); /* FIXME need a MVM_nativeref_write_lex_u */
+            MVM_nativeref_write_lex_u(tc, cont, value);
             break;
         case MVM_NATIVEREF_ATTRIBUTE:
             MVM_nativeref_write_attribute_u(tc, cont, value);
@@ -720,14 +720,13 @@ static void native_ref_configure_container_spec(MVMThreadContext *tc, MVMSTable
 }
 
 void *MVM_container_devirtualize_fetch_for_jit(MVMThreadContext *tc, MVMSTable *st, MVMuint16 type) {
-    if (type != MVM_reg_int64)
-        return NULL;
     if (st->container_spec == &native_ref_spec) {
         MVMNativeRefREPRData *repr_data = (MVMNativeRefREPRData *)st->REPR_data;
         switch (repr_data->ref_kind) {
             case MVM_NATIVEREF_LEX:
                 switch (type) {
                     case MVM_reg_int64: return MVM_nativeref_read_lex_i;
+                    case MVM_reg_uint64: return MVM_nativeref_read_lex_i;
                     case MVM_reg_num64: return MVM_nativeref_read_lex_n;
                     case MVM_reg_str:   return MVM_nativeref_read_lex_s;
                 }
@@ -735,6 +734,7 @@ void *MVM_container_devirtualize_fetch_for_jit(MVMThreadContext *tc, MVMSTable *
             case MVM_NATIVEREF_ATTRIBUTE:
                 switch (type) {
                     case MVM_reg_int64: return MVM_nativeref_read_attribute_i;
+                    case MVM_reg_uint64: return MVM_nativeref_read_attribute_u;
                     case MVM_reg_num64: return MVM_nativeref_read_attribute_n;
                     case MVM_reg_str:   return MVM_nativeref_read_attribute_s;
                 }
@@ -742,6 +742,7 @@ void *MVM_container_devirtualize_fetch_for_jit(MVMThreadContext *tc, MVMSTable *
             case MVM_NATIVEREF_POSITIONAL:
                 switch (type) {
                     case MVM_reg_int64: return MVM_nativeref_read_positional_i;
+                    case MVM_reg_uint64: return MVM_nativeref_read_positional_u;
                     case MVM_reg_num64: return MVM_nativeref_read_positional_n;
                     case MVM_reg_str:   return MVM_nativeref_read_positional_s;
                 }
@@ -749,6 +750,7 @@ void *MVM_container_devirtualize_fetch_for_jit(MVMThreadContext *tc, MVMSTable *
             case MVM_NATIVEREF_MULTIDIM:
                 switch (type) {
                     case MVM_reg_int64: return MVM_nativeref_read_multidim_i;
+                    case MVM_reg_uint64: return MVM_nativeref_read_multidim_u;
                     case MVM_reg_num64: return MVM_nativeref_read_multidim_n;
                     case MVM_reg_str:   return MVM_nativeref_read_multidim_s;
                 }
@@ -761,14 +763,13 @@ void *MVM_container_devirtualize_fetch_for_jit(MVMThreadContext *tc, MVMSTable *
 }
 
 void *MVM_container_devirtualize_store_for_jit(MVMThreadContext *tc, MVMSTable *st, MVMuint16 type) {
-    if (type != MVM_reg_int64)
-        return NULL;
     if (st->container_spec == &native_ref_spec) {
         MVMNativeRefREPRData *repr_data = (MVMNativeRefREPRData *)st->REPR_data;
         switch (repr_data->ref_kind) {
             case MVM_NATIVEREF_LEX:
                 switch (type) {
                     case MVM_reg_int64: return MVM_nativeref_write_lex_i;
+                    case MVM_reg_uint64: return MVM_nativeref_write_lex_u;
                     case MVM_reg_num64: return MVM_nativeref_write_lex_n;
                     case MVM_reg_str:   return MVM_nativeref_write_lex_s;
                 }
@@ -776,6 +777,7 @@ void *MVM_container_devirtualize_store_for_jit(MVMThreadContext *tc, MVMSTable *
             case MVM_NATIVEREF_ATTRIBUTE:
                 switch (type) {
                     case MVM_reg_int64: return MVM_nativeref_write_attribute_i;
+                    case MVM_reg_uint64: return MVM_nativeref_write_attribute_u;
                     case MVM_reg_num64: return MVM_nativeref_write_attribute_n;
                     case MVM_reg_str:   return MVM_nativeref_write_attribute_s;
                 }
@@ -783,6 +785,7 @@ void *MVM_container_devirtualize_store_for_jit(MVMThreadContext *tc, MVMSTable *
             case MVM_NATIVEREF_POSITIONAL:
                 switch (type) {
                     case MVM_reg_int64: return MVM_nativeref_write_positional_i;
+                    case MVM_reg_uint64: return MVM_nativeref_write_positional_u;
                     case MVM_reg_num64: return MVM_nativeref_write_positional_n;
                     case MVM_reg_str:   return MVM_nativeref_write_positional_s;
                 }
@@ -790,6 +793,7 @@ void *MVM_container_devirtualize_store_for_jit(MVMThreadContext *tc, MVMSTable *
             case MVM_NATIVEREF_MULTIDIM:
                 switch (type) {
                     case MVM_reg_int64: return MVM_nativeref_write_multidim_i;
+                    case MVM_reg_uint64: return MVM_nativeref_write_multidim_u;
                     case MVM_reg_num64: return MVM_nativeref_write_multidim_n;
                     case MVM_reg_str:   return MVM_nativeref_write_multidim_s;
                 }
