@@ -8,11 +8,11 @@ static const MVMREPROps CArray_this_repr;
 static MVMObject * type_object_for(MVMThreadContext *tc, MVMObject *HOW) {
     MVMSTable *st = MVM_gc_allocate_stable(tc, &CArray_this_repr, HOW);
 
-    MVMROOT(tc, st, {
+    MVMROOT(tc, st) {
         MVMObject *obj = MVM_gc_allocate_type_object(tc, st);
         MVM_ASSIGN_REF(tc, &(st->header), st->WHAT, obj);
         st->size = sizeof(MVMCArray);
-    });
+    }
 
     return st->WHAT;
 }
@@ -308,12 +308,12 @@ static void at_pos(MVMThreadContext *tc, MVMSTable *st, MVMObject *root, void *d
                 /* If not, we need to produce and cache it. */
                 else {
                     void **storage = (void **)body->storage;
-                    MVMROOT(tc, root, {
+                    MVMROOT(tc, root) {
                         MVMObject **child_objs = body->child_objs;
                         MVMObject *wrapped = make_wrapper(tc, st, storage[index]);
                         MVM_ASSIGN_REF(tc, &(root->header), child_objs[index], wrapped);
                         value->o = wrapped;
-                    });
+                    }
                 }
             }
             else {
@@ -335,12 +335,12 @@ static void at_pos(MVMThreadContext *tc, MVMSTable *st, MVMObject *root, void *d
                 /* No cached object, but non-NULL pointer in array. Construct object,
                  * put it in the cache and return it. */
                 else if (storage[index]) {
-                    MVMROOT(tc, root, {
+                    MVMROOT(tc, root) {
                         MVMObject **child_objs = body->child_objs;
                         MVMObject *wrapped = make_wrapper(tc, st, storage[index]);
                         MVM_ASSIGN_REF(tc, &(root->header), child_objs[index], wrapped);
                         value->o = wrapped;
-                    });
+                    }
                 }
 
                 /* NULL pointer in the array; result is the type object. */
