@@ -9,11 +9,11 @@ static const MVMREPROps MVMCompUnit_this_repr;
 static MVMObject * type_object_for(MVMThreadContext *tc, MVMObject *HOW) {
     MVMSTable *st = MVM_gc_allocate_stable(tc, &MVMCompUnit_this_repr, HOW);
 
-    MVMROOT(tc, st, {
+    MVMROOT(tc, st) {
         MVMObject *obj = MVM_gc_allocate_type_object(tc, st);
         MVM_ASSIGN_REF(tc, &(st->header), st->WHAT, obj);
         st->size = sizeof(MVMCompUnit);
-    });
+    }
 
     return st->WHAT;
 }
@@ -63,6 +63,8 @@ static void gc_mark(MVMThreadContext *tc, MVMSTable *st, void *data, MVMGCWorkli
     /* Add various other referenced strings, etc. */
     MVM_gc_worklist_add(tc, worklist, &body->hll_name);
     MVM_gc_worklist_add(tc, worklist, &body->filename);
+    MVM_gc_worklist_add(tc, worklist, &body->resolver);
+    MVM_gc_worklist_add(tc, worklist, &body->dynamic_resolver);
 }
 
 /* Called by the VM in order to free memory associated with this object. */
@@ -80,17 +82,11 @@ static void gc_free(MVMThreadContext *tc, MVMObject *obj) {
     MVM_free(body->inline_tweak_mutex);
     MVM_free(body->coderefs);
     if (body->callsites)
-        MVM_fixed_size_free(tc, tc->instance->fsa,
-            body->num_callsites * sizeof(MVMCallsite *),
-            body->callsites);
+        MVM_free(body->callsites);
     if (body->extops)
-        MVM_fixed_size_free(tc, tc->instance->fsa,
-            body->num_extops * sizeof(MVMExtOpRecord),
-            body->extops);
+        MVM_free(body->extops);
     if (body->strings)
-        MVM_fixed_size_free(tc, tc->instance->fsa,
-            body->num_strings * sizeof(MVMString *),
-            body->strings);
+        MVM_free(body->strings);
     MVM_free(body->scs);
     MVM_free(body->scs_to_resolve);
     MVM_free(body->sc_handle_idxs);
