@@ -8,11 +8,11 @@ static const MVMREPROps MVMContext_this_repr;
 static MVMObject * type_object_for(MVMThreadContext *tc, MVMObject *HOW) {
     MVMSTable *st = MVM_gc_allocate_stable(tc, &MVMContext_this_repr, HOW);
 
-    MVMROOT(tc, st, {
+    MVMROOT(tc, st) {
         MVMObject *obj = MVM_gc_allocate_type_object(tc, st);
         MVM_ASSIGN_REF(tc, &(st->header), st->WHAT, obj);
         st->size = sizeof(MVMContext);
-    });
+    }
 
     return st->WHAT;
 }
@@ -298,11 +298,11 @@ MVMObject * MVM_context_from_frame(MVMThreadContext *tc, MVMFrame *f) {
     MVMObject *ctx;
     f = MVM_frame_force_to_heap(tc, f);
     snapshot_frame_callees(tc, f);
-    MVMROOT(tc, f, {
+    MVMROOT(tc, f) {
         ctx = MVM_repr_alloc_init(tc, tc->instance->boot_types.BOOTContext);
         MVM_ASSIGN_REF(tc, &(ctx->header), ((MVMContext *)ctx)->body.context, f);
         ((MVMContext *)ctx)->body.traversable = 1;
-    });
+    }
     return ctx;
 }
 
@@ -311,10 +311,10 @@ MVMObject * MVM_context_from_frame(MVMThreadContext *tc, MVMFrame *f) {
 MVMObject * MVM_context_from_frame_non_traversable(MVMThreadContext *tc, MVMFrame *f) {
     MVMObject *ctx;
     f = MVM_frame_force_to_heap(tc, f);
-    MVMROOT(tc, f, {
+    MVMROOT(tc, f) {
         ctx = MVM_repr_alloc_init(tc, tc->instance->boot_types.BOOTContext);
         MVM_ASSIGN_REF(tc, &(ctx->header), ((MVMContext *)ctx)->body.context, f);
-    });
+    }
     return ctx;
 }
 
@@ -348,9 +348,9 @@ MVMObject * MVM_context_apply_traversal(MVMThreadContext *tc, MVMContext *ctx, M
     if (traversal_exists(tc, ctx->body.context, new_traversals, new_num_traversals)) {
         /* Yes, make a new context object and return it. */
         MVMContext *result;
-        MVMROOT(tc, ctx, {
+        MVMROOT(tc, ctx) {
             result = (MVMContext *)MVM_repr_alloc_init(tc, tc->instance->boot_types.BOOTContext);
-        });
+        }
         MVM_ASSIGN_REF(tc, &(result->common.header), result->body.context, ctx->body.context);
         result->body.traversals = new_traversals;
         result->body.num_traversals = new_num_traversals;
