@@ -8,11 +8,11 @@ static const MVMREPROps MVMStaticFrame_this_repr;
 static MVMObject * type_object_for(MVMThreadContext *tc, MVMObject *HOW) {
     MVMSTable *st = MVM_gc_allocate_stable(tc, &MVMStaticFrame_this_repr, HOW);
 
-    MVMROOT(tc, st, {
+    MVMROOT(tc, st) {
         MVMObject *obj = MVM_gc_allocate_type_object(tc, st);
         MVM_ASSIGN_REF(tc, &(st->header), st->WHAT, obj);
         st->size = sizeof(MVMStaticFrame);
-    });
+    }
 
     return st->WHAT;
 }
@@ -154,7 +154,8 @@ static void gc_mark(MVMThreadContext *tc, MVMSTable *st, void *data, MVMGCWorkli
                 MVM_gc_worklist_add(tc, worklist, &body->static_env[i].o);
     }
 
-    /* Spesh. */
+    /* Inline cache and spesh. */
+    MVM_disp_inline_cache_mark(tc, &(body->inline_cache), worklist);
     MVM_gc_worklist_add(tc, worklist, &body->spesh);
 
     /* Debug symbols. */
@@ -191,6 +192,7 @@ static void gc_free(MVMThreadContext *tc, MVMObject *obj) {
     MVM_free(body->lexical_names_list);
     MVM_free(body->instrumentation);
     MVM_index_hash_demolish(tc, &body->lexical_names);
+    MVM_disp_inline_cache_destroy(tc, &(body->inline_cache));
 }
 
 static const MVMStorageSpec storage_spec = {
