@@ -13,9 +13,9 @@ MVMObject * MVM_sc_create(MVMThreadContext *tc, MVMString *handle) {
     }
 
     /* Allocate. */
-    MVMROOT(tc, handle, {
+    MVMROOT(tc, handle) {
         sc = (MVMSerializationContext *)REPR(tc->instance->SCRef)->allocate(tc, STABLE(tc->instance->SCRef));
-        MVMROOT(tc, sc, {
+        MVMROOT(tc, sc) {
             /* Add to weak lookup hash. */
             uv_mutex_lock(&tc->instance->mutex_sc_registry);
             struct MVMSerializationContextWeakHashEntry *entry
@@ -56,8 +56,8 @@ MVMObject * MVM_sc_create(MVMThreadContext *tc, MVMString *handle) {
                 }
             }
             uv_mutex_unlock(&tc->instance->mutex_sc_registry);
-        });
-    });
+        }
+    }
 
     return (MVMObject *)sc;
 }
@@ -198,7 +198,7 @@ MVMSerializationContext * MVM_sc_get_sc_slow(MVMThreadContext *tc, MVMCompUnit *
 /* Checks if an SC is currently in the process of doing deserialization work. */
 MVM_STATIC_INLINE MVMint64 sc_working(MVMSerializationContext *sc) {
     MVMSerializationReader *sr = sc->body->sr;
-    return sr && sr->working;
+    return sr && MVM_load(&sr->working);
 }
 
 MVMuint8 MVM_sc_is_object_immediately_available(MVMThreadContext *tc, MVMSerializationContext *sc, MVMint64 idx) {
