@@ -7,6 +7,9 @@ static MVMCallsite   zero_arity_callsite = { NULL, 0, 0, 0, 0, 0, NULL };
 static MVMCallsiteEntry obj_arg_flags[] = { MVM_CALLSITE_ARG_OBJ };
 static MVMCallsite     obj_callsite = { obj_arg_flags, 1, 1, 1, 0, 0, NULL };
 
+static MVMCallsiteEntry str_arg_flags[] = { MVM_CALLSITE_ARG_STR };
+static MVMCallsite     str_callsite = { str_arg_flags, 1, 1, 1, 0, 0, NULL };
+
 static MVMCallsiteEntry int_arg_flags[] = { MVM_CALLSITE_ARG_INT };
 static MVMCallsite     int_callsite = { int_arg_flags, 1, 1, 1, 0, 0, NULL };
 
@@ -44,10 +47,8 @@ void MVM_callsite_initialize_common(MVMThreadContext *tc) {
     /* Initialize the intern storage. */
     MVMCallsiteInterns *interns = tc->instance->callsite_interns;
     interns->max_arity = MVM_INTERN_ARITY_SOFT_LIMIT - 1;
-    interns->by_arity = MVM_fixed_size_alloc_zeroed(tc, tc->instance->fsa,
-            MVM_INTERN_ARITY_SOFT_LIMIT * sizeof(MVMCallsite **));
-    interns->num_by_arity = MVM_fixed_size_alloc_zeroed(tc, tc->instance->fsa,
-            MVM_INTERN_ARITY_SOFT_LIMIT * sizeof(MVMuint32));
+    interns->by_arity = MVM_calloc(MVM_INTERN_ARITY_SOFT_LIMIT, sizeof(MVMCallsite **));
+    interns->num_by_arity = MVM_calloc(MVM_INTERN_ARITY_SOFT_LIMIT, sizeof(MVMuint32));
 
     /* Intern callsites.
      * If you add a callsite to this list, remember to add it to the check in
@@ -57,6 +58,8 @@ void MVM_callsite_initialize_common(MVMThreadContext *tc) {
     MVM_callsite_intern(tc, &ptr, 0, 1);
     ptr = &obj_callsite;
     MVM_callsite_intern(tc, &ptr, 0, 1);
+    ptr = &str_callsite;
+    MVM_callsite_intern(tc, &ptr, 0, 1);
     ptr = &int_callsite;
     MVM_callsite_intern(tc, &ptr, 0, 1);
     ptr = &obj_obj_callsite;
@@ -82,6 +85,8 @@ MVM_PUBLIC MVMCallsite * MVM_callsite_get_common(MVMThreadContext *tc, MVMCommon
             return &zero_arity_callsite;
         case MVM_CALLSITE_ID_OBJ:
             return &obj_callsite;
+        case MVM_CALLSITE_ID_STR:
+            return &str_callsite;
         case MVM_CALLSITE_ID_INT:
             return &int_callsite;
         case MVM_CALLSITE_ID_OBJ_OBJ:
@@ -258,12 +263,12 @@ MVM_PUBLIC void MVM_callsite_intern(MVMThreadContext *tc, MVMCallsite **cs_ptr,
         if (num_flags > interns->max_arity) {
             MVMuint32 prev_elems = interns->max_arity + 1;
             MVMuint32 new_elems = num_flags + 1;
-            interns->by_arity = MVM_fixed_size_realloc_at_safepoint(tc, tc->instance->fsa,
+            interns->by_arity = MVM_realloc_at_safepoint(tc,
                     interns->by_arity,
                     prev_elems * sizeof(MVMCallsite **),
                     new_elems * sizeof(MVMCallsite **));
             memset(interns->by_arity + prev_elems, 0, (new_elems - prev_elems) * sizeof(MVMCallsite *));
-            interns->num_by_arity = MVM_fixed_size_realloc_at_safepoint(tc, tc->instance->fsa,
+            interns->num_by_arity = MVM_realloc_at_safepoint(tc,
                     interns->num_by_arity,
                     prev_elems * sizeof(MVMuint32),
                     new_elems * sizeof(MVMuint32));
@@ -276,12 +281,11 @@ MVM_PUBLIC void MVM_callsite_intern(MVMThreadContext *tc, MVMCallsite **cs_ptr,
         MVMuint32 cur_size = interns->num_by_arity[num_flags];
         if (cur_size % MVM_INTERN_ARITY_GROW == 0) {
             interns->by_arity[num_flags] = cur_size != 0
-                ? MVM_fixed_size_realloc_at_safepoint(tc, tc->instance->fsa,
+                ? MVM_realloc_at_safepoint(tc,
                     interns->by_arity[num_flags],
                     cur_size * sizeof(MVMCallsite *),
                     (cur_size + MVM_INTERN_ARITY_GROW) * sizeof(MVMCallsite *))
-                : MVM_fixed_size_alloc(tc, tc->instance->fsa, 
-                    MVM_INTERN_ARITY_GROW * sizeof(MVMCallsite *));
+                : MVM_malloc(MVM_INTERN_ARITY_GROW * sizeof(MVMCallsite *));
         }
 
         /* Install the new callsite. */
@@ -324,6 +328,7 @@ void MVM_callsite_mark_interns(MVMThreadContext *tc, MVMGCWorklist *worklist,
 static int is_common(MVMCallsite *cs) {
     return cs == &zero_arity_callsite   ||
            cs == &obj_callsite          ||
+           cs == &str_callsite          ||
            cs == &int_callsite          ||
            cs == &obj_obj_callsite      ||
            cs == &obj_str_callsite      ||
@@ -346,17 +351,11 @@ void MVM_callsite_cleanup_interns(MVMInstance *instance) {
                 if (!is_common(callsite))
                     MVM_callsite_destroy(callsite);
             }
-            MVM_fixed_size_free(instance->main_thread, instance->fsa,
-                    callsite_count * sizeof(MVMCallsite *),
-                    callsites);
+            MVM_free(callsites);
         }
     }
-    MVM_fixed_size_free(instance->main_thread, instance->fsa,
-            interns->max_arity * sizeof(MVMCallsite **),
-            interns->by_arity);
-    MVM_fixed_size_free(instance->main_thread, instance->fsa,
-            interns->max_arity * sizeof(MVMuint32),
-            interns->num_by_arity);
+    MVM_free(interns->by_arity);
+    MVM_free(interns->num_by_arity);
     MVM_free(instance->callsite_interns);
 }
 
