@@ -282,50 +282,49 @@ double MVM_nativecall_unmarshal_double(MVMThreadContext *tc, MVMObject *value) {
     return (double)MVM_repr_get_num(tc, value);
 }
 
+char * MVM_nativecall_encode_string(MVMThreadContext *tc, MVMString *value_str, MVMint16 type, MVMint16 *free, MVMint16 unmarshal_kind, const MVMREPROps *repr) {
+    /* Encode string. */
+    char *str;
+    switch (type & MVM_NATIVECALL_ARG_TYPE_MASK) {
+        case MVM_NATIVECALL_ARG_ASCIISTR:
+            str = MVM_string_ascii_encode_malloc(tc, value_str);
+            break;
+        case MVM_NATIVECALL_ARG_UTF16STR:
+        {
+            MVMuint64 output_size;
+            /* This adds a (two byte) U-0000 at the end, but doesn't include
+             * that code point in the returned output_size. */
+            char *temp = MVM_string_utf16_encode_substr(tc, value_str, &output_size, 0, -1, NULL, 0);
+            /* output_size is in 2 byte units, and doesn't include the
+             * terminating U-0000, which was written. */
+            size_t octet_len = 2 * (output_size + 1);
+            str = malloc(octet_len);
+            memcpy(str, temp, octet_len);
+            MVM_free(temp);
+            break;
+        }
+        default:
+            str = MVM_string_utf8_encode_C_string_malloc(tc, value_str);
+    }
+
+
+    /* Set whether to free it or not. */
+    if (free) {
+        if (repr->ID == MVM_REPR_ID_MVMCStr)
+            *free = 0; /* Manually managed. */
+        else if (type & MVM_NATIVECALL_ARG_FREE_STR_MASK)
+            *free = 1;
+        else
+            *free = 0;
+    }
+
+    return str;
+}
+
 char * MVM_nativecall_unmarshal_string(MVMThreadContext *tc, MVMObject *value, MVMint16 type, MVMint16 *free, MVMint16 unmarshal_kind) {
-    if (IS_CONCRETE(value)) {
-        MVMString *value_str = MVM_repr_get_str(tc, value);
-
-        /* Encode string. */
-        char *str;
-        switch (type & MVM_NATIVECALL_ARG_TYPE_MASK) {
-            case MVM_NATIVECALL_ARG_ASCIISTR:
-                str = MVM_string_ascii_encode_malloc(tc, value_str);
-                break;
-            case MVM_NATIVECALL_ARG_UTF16STR:
-            {
-                MVMuint64 output_size;
-                /* This adds a (two byte) U-0000 at the end, but doesn't include
-                 * that code point in the returned output_size. */
-                char *temp = MVM_string_utf16_encode_substr(tc, value_str, &output_size, 0, -1, NULL, 0);
-                /* output_size is in 2 byte units, and doesn't include the
-                 * terminating U-0000, which was written. */
-                size_t octet_len = 2 * (output_size + 1);
-                str = malloc(octet_len);
-                memcpy(str, temp, octet_len);
-                MVM_free(temp);
-                break;
-            }
-            default:
-                str = MVM_string_utf8_encode_C_string_malloc(tc, value_str);
-        }
-
-
-        /* Set whether to free it or not. */
-        if (free) {
-            if (REPR(value)->ID == MVM_REPR_ID_MVMCStr)
-                *free = 0; /* Manually managed. */
-            else if (free && type & MVM_NATIVECALL_ARG_FREE_STR_MASK)
-                *free = 1;
-            else
-                *free = 0;
-        }
-
-        return str;
-    }
-    else {
-        return NULL;
-    }
+    return IS_CONCRETE(value)
+        ? MVM_nativecall_encode_string(tc, MVM_repr_get_str(tc, value), type, free, unmarshal_kind, REPR(value))
+        : NULL;
 }
 
 MVM_NO_RETURN static void unmarshal_error(MVMThreadContext *tc, char *desired_repr, MVMObject *value, MVMint16 unmarshal_kind) MVM_NO_RETURN_ATTRIBUTE;
@@ -540,7 +539,7 @@ MVMint8 MVM_nativecall_build(MVMThreadContext *tc, MVMObject *site, MVMString *l
 static MVMObject * nativecall_cast(MVMThreadContext *tc, MVMObject *target_spec, MVMObject *target_type, void *cpointer_body) {
     MVMObject *result = NULL;
 
-    MVMROOT2(tc, target_spec, target_type, {
+    MVMROOT2(tc, target_spec, target_type) {
         switch (REPR(target_type)->ID) {
             case MVM_REPR_ID_P6opaque: {
                 const MVMStorageSpec *ss = REPR(target_spec)->get_storage_spec(tc, STABLE(target_spec));
@@ -678,7 +677,7 @@ static MVMObject * nativecall_cast(MVMThreadContext *tc, MVMObject *target_spec,
             default:
                 MVM_exception_throw_adhoc(tc, "Internal error: unhandled target type");
         }
-    });
+    }
 
     return result;
 }
