@@ -486,9 +486,9 @@ MVMObject * MVM_nativecall_invoke(MVMThreadContext *tc, MVMObject *res_type,
      * shall need, since later we may allocate a result and and move it. */
     MVMNativeCallBody *body = MVM_nativecall_get_nc_body(tc, site);
     if (MVM_UNLIKELY(!body->lib_handle)) {
-        MVMROOT3(tc, site, args, res_type, {
+        MVMROOT3(tc, site, args, res_type) {
             MVM_nativecall_restore_library(tc, body, site);
-        });
+        }
         body = MVM_nativecall_get_nc_body(tc, site);
     }
     MVMint16  num_args    = body->num_args;
@@ -616,7 +616,7 @@ MVMObject * MVM_nativecall_invoke(MVMThreadContext *tc, MVMObject *res_type,
     }
 
 
-    MVMROOT3(tc, args, res_type, result, {
+    MVMROOT3(tc, args, res_type, result) {
         MVM_gc_mark_thread_blocked(tc);
         if (result) {
             /* We are calling a C++ constructor so we hand back the invocant (THIS) we recorded earlier. */
@@ -719,7 +719,7 @@ MVMObject * MVM_nativecall_invoke(MVMThreadContext *tc, MVMObject *res_type,
                     MVM_exception_throw_adhoc(tc, "Internal error: unhandled libffi return type");
             }
         }
-    });
+    }
 
     for (i = 0; i < num_args; i++) {
         MVMObject *value = MVM_repr_at_pos_o(tc, args, i);
@@ -859,9 +859,9 @@ void MVM_nativecall_dispatch(MVMThreadContext *tc, MVMObject *res_type,
      * shall need, since later we may allocate a result and and move it. */
     MVMNativeCallBody *body = MVM_nativecall_get_nc_body(tc, site);
     if (MVM_UNLIKELY(!body->lib_handle)) {
-        MVMROOT2(tc, site, res_type, {
+        MVMROOT2(tc, site, res_type) {
             MVM_nativecall_restore_library(tc, body, site);
-        });
+        }
         body = MVM_nativecall_get_nc_body(tc, site);
     }
     MVMint16  num_args    = body->num_args;
@@ -1078,18 +1078,9 @@ void MVM_nativecall_dispatch(MVMThreadContext *tc, MVMObject *res_type,
                 case MVM_NATIVECALL_ARG_UTF8STR:
                 case MVM_NATIVECALL_ARG_UTF16STR:
                     {
-                        char *str;
-                        switch (arg_types[i] & MVM_NATIVECALL_ARG_TYPE_MASK) {
-                            case MVM_NATIVECALL_ARG_ASCIISTR:
-                                str = MVM_string_ascii_encode_any(tc, value);
-                                break;
-                            case MVM_NATIVECALL_ARG_UTF16STR:
-                                str = MVM_string_utf16_encode(tc, value, 0);
-                                break;
-                            default:
-                                str = MVM_string_utf8_encode_C_string(tc, value);
-                        }
-                        if (arg_types[i] & MVM_NATIVECALL_ARG_FREE_STR_MASK) {
+                        MVMint16 free = 0;
+                        char *str = MVM_nativecall_encode_string(tc, value, arg_types[i], &free, i, REPR(value));
+                        if (free) {
                             if (!free_strs)
                                 free_strs = (char**)alloca(num_args * sizeof(char *));
                             free_strs[num_strs] = str;
@@ -1112,7 +1103,7 @@ void MVM_nativecall_dispatch(MVMThreadContext *tc, MVMObject *res_type,
     }
 
 
-    MVMROOT2(tc, res_type, result, {
+    MVMROOT2(tc, res_type, result) {
         MVM_gc_mark_thread_blocked(tc);
         if (result) {
             /* We are calling a C++ constructor so we hand back the invocant (THIS) we recorded earlier. */
@@ -1194,6 +1185,10 @@ void MVM_nativecall_dispatch(MVMThreadContext *tc, MVMObject *res_type,
                         update_rws(tc, values, num_args, arg_types, args, interval_id);
                         MVM_args_set_dispatch_result_int(tc, tc->cur_frame, (MVMuint64)ret);
                     }
+                    else if (tc->cur_frame->return_type == MVM_RETURN_UINT) {
+                        update_rws(tc, values, num_args, arg_types, args, interval_id);
+                        MVM_args_set_dispatch_result_uint(tc, tc->cur_frame, (MVMuint64)ret);
+                    }
                     else {
                         result = MVM_nativecall_make_cpointer(tc, res_type, ret);
 
@@ -1226,19 +1221,19 @@ void MVM_nativecall_dispatch(MVMThreadContext *tc, MVMObject *res_type,
                     break;
                 }
                 case MVM_NATIVECALL_ARG_UCHAR:
-                    handle_ret_and_rws(tc, unsigned char, ffi_arg, MVM_args_set_dispatch_result_int);
+                    handle_ret_and_rws(tc, unsigned char, ffi_arg, MVM_args_set_dispatch_result_uint);
                     break;
                 case MVM_NATIVECALL_ARG_USHORT:
-                    handle_ret_and_rws(tc, unsigned short, ffi_arg, MVM_args_set_dispatch_result_int);
+                    handle_ret_and_rws(tc, unsigned short, ffi_arg, MVM_args_set_dispatch_result_uint);
                     break;
                 case MVM_NATIVECALL_ARG_UINT:
-                    handle_ret_and_rws(tc, unsigned int, ffi_arg, MVM_args_set_dispatch_result_int);
+                    handle_ret_and_rws(tc, unsigned int, ffi_arg, MVM_args_set_dispatch_result_uint);
                     break;
                 case MVM_NATIVECALL_ARG_ULONG:
-                    handle_ret_and_rws(tc, unsigned long, ffi_arg, MVM_args_set_dispatch_result_int);
+                    handle_ret_and_rws(tc, unsigned long, ffi_arg, MVM_args_set_dispatch_result_uint);
                     break;
                 case MVM_NATIVECALL_ARG_ULONGLONG:
-                    handle_ret_and_rws(tc, unsigned long long, ffi_arg, MVM_args_set_dispatch_result_int);
+                    handle_ret_and_rws(tc, unsigned long long, ffi_arg, MVM_args_set_dispatch_result_uint);
                     break;
                 default:
                     MVM_gc_mark_thread_unblocked(tc);
@@ -1247,12 +1242,16 @@ void MVM_nativecall_dispatch(MVMThreadContext *tc, MVMObject *res_type,
                         "in MVM_nativecall_dispatch", ret_type & MVM_NATIVECALL_ARG_TYPE_MASK);
             }
         }
-    });
+    }
 
     /* Free any memory that we need to. */
     if (free_strs)
         for (i = 0; i < num_strs; i++)
+#ifdef MVM_USE_MIMALLOC
+            free(free_strs[i]);
+#else
             MVM_free(free_strs[i]);
+#endif
 
     MVM_telemetry_interval_stop(tc, interval_id, "nativecall invoke");
 }
