@@ -6,11 +6,8 @@ MVM_STATIC_INLINE void hash_demolish_internal(MVMThreadContext *tc,
                                               struct MVMUniHashTableControl *control) {
     size_t allocated_items = MVM_uni_hash_allocated_items(control);
     size_t entries_size = sizeof(struct MVMUniHashEntry) * allocated_items;
-    size_t metadata_size = MVM_hash_round_size_up(allocated_items + 1);
-    size_t total_size
-        = entries_size + sizeof(struct MVMUniHashTableControl) + metadata_size;
     char *start = (char *)control - entries_size;
-    MVM_fixed_size_free(tc, tc->instance->fsa, total_size, start);
+    MVM_free(start);
 }
 
 /* Frees the entire contents of the hash, leaving you just the hashtable itself,
@@ -43,7 +40,7 @@ MVM_STATIC_INLINE struct MVMUniHashTableControl *hash_allocate_common(MVMThreadC
     assert(total_size == MVM_hash_round_size_up(total_size));
 
     struct MVMUniHashTableControl *control =
-        (struct MVMUniHashTableControl *) ((char *)MVM_fixed_size_alloc(tc, tc->instance->fsa, total_size) + entries_size);
+        (struct MVMUniHashTableControl *) ((char *)MVM_malloc(total_size) + entries_size);
 
     control->official_size_log2 = official_size_log2;
     control->max_items = max_items;
