@@ -9,21 +9,21 @@ static MVMuint32 try_update_cache_entry(MVMThreadContext *tc, MVMDispInlineCache
  * Inline caching of getlexstatic_o
  **/
 
-static MVMObject * getlexstatic_initial(MVMThreadContext *tc,
-        MVMDispInlineCacheEntry **entry_ptr, MVMString *name);
-static MVMObject * getlexstatic_resolved(MVMThreadContext *tc,
-        MVMDispInlineCacheEntry **entry_ptr, MVMString *name);
+static int getlexstatic_initial(MVMThreadContext *tc,
+        MVMDispInlineCacheEntry **entry_ptr, MVMString *name, MVMRegister *r);
+static int getlexstatic_resolved(MVMThreadContext *tc,
+        MVMDispInlineCacheEntry **entry_ptr, MVMString *name, MVMRegister *r);
 
 /* Unlinked node. */
 static MVMDispInlineCacheEntry unlinked_getlexstatic = { getlexstatic_initial };
 
 /* Initial unlinked handler. */
-static MVMObject * getlexstatic_initial(MVMThreadContext *tc,
-        MVMDispInlineCacheEntry **entry_ptr, MVMString *name) {
+static int getlexstatic_initial(MVMThreadContext *tc,
+        MVMDispInlineCacheEntry **entry_ptr, MVMString *name, MVMRegister *r) {
     /* Do the lookup. */
-    MVMRegister r;
-    int found = MVM_frame_find_lexical_by_name(tc, name, MVM_reg_obj, &r);
-    MVMObject *result = found ? r.o : tc->instance->VMNull;
+    int found = MVM_frame_find_lexical_by_name(tc, name, MVM_reg_obj, r);
+    MVMObject *result = found > 0 ? r->o : tc->instance->VMNull;
+    // FIXME if the fallback resolver is used we must not cace the VMNull
 
     /* Set up result node and try to install it. */
     MVMStaticFrame *sf = tc->cur_frame->static_info;
@@ -32,16 +32,17 @@ static MVMObject * getlexstatic_initial(MVMThreadContext *tc,
     MVM_ASSIGN_REF(tc, &(sf->common.header), new_entry->result, result);
     try_update_cache_entry(tc, entry_ptr, &unlinked_getlexstatic, &(new_entry->base));
 
-    return result;
+    return found;
 }
 
 /* Once resolved, just hand back the result. */
-static MVMObject * getlexstatic_resolved(MVMThreadContext *tc,
-        MVMDispInlineCacheEntry **entry_ptr, MVMString *name) {
+static int getlexstatic_resolved(MVMThreadContext *tc,
+        MVMDispInlineCacheEntry **entry_ptr, MVMString *name, MVMRegister *r) {
     MVMDispInlineCacheEntryResolvedGetLexStatic *resolved =
         (MVMDispInlineCacheEntryResolvedGetLexStatic *)*entry_ptr;
     MVM_ASSERT_NOT_FROMSPACE(tc, resolved->result);
-    return resolved->result;
+    r->o = resolved->result;
+    return 1;
 }
 
 /**
@@ -104,9 +105,9 @@ static void dispatch_monomorphic(MVMThreadContext *tc,
     record->arg_info.source = source;
     record->arg_info.map = arg_indices;
     MVMint64 outcome;
-    MVMROOT2(tc, id, sf, {
+    MVMROOT2(tc, id, sf) {
         outcome = MVM_disp_program_run(tc, dp, record, cid, bytecode_offset, 0);
-    });
+    }
     if (!outcome) {
         /* Dispatch program failed. Remove this record and then record a new
          * dispatch program. */
@@ -135,9 +136,9 @@ static void dispatch_monomorphic_flattening(MVMThreadContext *tc,
                 dp->num_temporaries);
         record->arg_info = flat_record->arg_info;
         MVMint64 outcome;
-        MVMROOT2(tc, id, sf, {
+        MVMROOT2(tc, id, sf) {
             outcome = MVM_disp_program_run(tc, dp, record, cid, bytecode_offset, 0);
-        });
+        }
         if (outcome) {
             /* It matches, so we're ready to continue. */
             return;
@@ -175,9 +176,9 @@ static void dispatch_polymorphic(MVMThreadContext *tc,
     MVMint32 i;
     for (i = entry->num_dps - 1; i >= 0; i--) {
         MVMint64 outcome;
-        MVMROOT2(tc, id, sf, {
+        MVMROOT2(tc, id, sf) {
             outcome = MVM_disp_program_run(tc, entry->dps[i], record, cid, bytecode_offset, i);
-        });
+        }
         if (outcome)
             return;
     }
@@ -211,9 +212,9 @@ static void dispatch_polymorphic_flattening(MVMThreadContext *tc,
     for (i = entry->num_dps - 1; i >= 0; i--) {
         if (flat_record->arg_info.callsite == entry->flattened_css[i]) {
             MVMint64 outcome;
-            MVMROOT2(tc, id, sf, {
+            MVMROOT2(tc, id, sf) {
                 outcome = MVM_disp_program_run(tc, entry->dps[i], record, cid, bytecode_offset, i);
-            });
+            }
             if (outcome)
                 return;
         }
