@@ -57,13 +57,13 @@ static void push_name_and_port(MVMThreadContext *tc, struct sockaddr_storage *na
                 return;
                 break;
         }
-        MVMROOT(tc, arr, {
+        MVMROOT(tc, arr) {
             port_o = MVM_repr_box_int(tc, tc->instance->boot_types.BOOTInt, port);
-            MVMROOT(tc, port_o, {
+            MVMROOT(tc, port_o) {
                 host_o = (MVMObject *)MVM_repr_box_str(tc, tc->instance->boot_types.BOOTStr,
                         MVM_string_ascii_decode_nt(tc, tc->instance->VMString, addrstr));
-            });
-        });
+            }
+        }
     } else {
         host_o = tc->instance->boot_types.BOOTStr;
         port_o = tc->instance->boot_types.BOOTInt;
@@ -92,7 +92,7 @@ static void on_read(uv_udp_t *handle, ssize_t nread, const uv_buf_t *buf, const
 
     MVM_repr_push_o(tc, arr, t->body.schedulee);
     if (nread >= 0) {
-        MVMROOT2(tc, t, arr, {
+        MVMROOT2(tc, t, arr) {
             MVMArray *res_buf;
 
             /* Push the sequence number. */
@@ -113,10 +113,10 @@ static void on_read(uv_udp_t *handle, ssize_t nread, const uv_buf_t *buf, const
 
             /* and finally, address and port */
             push_name_and_port(tc, (struct sockaddr_storage *)addr, arr);
-        });
+        }
     }
     else if (nread == UV_EOF) {
-        MVMROOT2(tc, t, arr, {
+        MVMROOT2(tc, t, arr) {
             MVMObject *final = MVM_repr_box_int(tc,
                 tc->instance->boot_types.BOOTInt, ri->seq_number);
             MVM_repr_push_o(tc, arr, final);
@@ -124,7 +124,7 @@ static void on_read(uv_udp_t *handle, ssize_t nread, const uv_buf_t *buf, const
             MVM_repr_push_o(tc, arr, tc->instance->boot_types.BOOTStr);
             MVM_repr_push_o(tc, arr, tc->instance->boot_types.BOOTStr);
             MVM_repr_push_o(tc, arr, tc->instance->boot_types.BOOTInt);
-        });
+        }
         if (buf->base)
             MVM_free(buf->base);
         uv_udp_recv_stop(handle);
@@ -133,7 +133,7 @@ static void on_read(uv_udp_t *handle, ssize_t nread, const uv_buf_t *buf, const
     else {
         MVM_repr_push_o(tc, arr, tc->instance->boot_types.BOOTInt);
         MVM_repr_push_o(tc, arr, tc->instance->boot_types.BOOTStr);
-        MVMROOT2(tc, t, arr, {
+        MVMROOT2(tc, t, arr) {
             MVMString *msg_str = MVM_string_ascii_decode_nt(tc,
                 tc->instance->VMString, uv_strerror(nread));
             MVMObject *msg_box = MVM_repr_box_str(tc,
@@ -141,7 +141,7 @@ static void on_read(uv_udp_t *handle, ssize_t nread, const uv_buf_t *buf, const
             MVM_repr_push_o(tc, arr, msg_box);
             MVM_repr_push_o(tc, arr, tc->instance->boot_types.BOOTStr);
             MVM_repr_push_o(tc, arr, tc->instance->boot_types.BOOTInt);
-        });
+        }
         if (buf->base)
             MVM_free(buf->base);
         uv_udp_recv_stop(handle);
@@ -165,20 +165,20 @@ static void read_setup(MVMThreadContext *tc, uv_loop_t *loop, MVMObject *async_t
     handle_data->handle->data = data;
     if ((r = uv_udp_recv_start(handle_data->handle, on_alloc, on_read)) < 0) {
         /* Error; need to notify. */
-        MVMROOT(tc, async_task, {
+        MVMROOT(tc, async_task) {
             MVMObject    *arr = MVM_repr_alloc_init(tc, tc->instance->boot_types.BOOTArray);
             MVM_repr_push_o(tc, arr, ((MVMAsyncTask *)async_task)->body.schedulee);
             MVM_repr_push_o(tc, arr, tc->instance->boot_types.BOOTInt);
             MVM_repr_push_o(tc, arr, tc->instance->boot_types.BOOTStr);
-            MVMROOT(tc, arr, {
+            MVMROOT(tc, arr) {
                 MVMString *msg_str = MVM_string_ascii_decode_nt(tc,
                     tc->instance->VMString, uv_strerror(r));
                 MVMObject *msg_box = MVM_repr_box_str(tc,
                     tc->instance->boot_types.BOOTStr, msg_str);
                 MVM_repr_push_o(tc, arr, msg_box);
-            });
+            }
             MVM_repr_push_o(tc, ((MVMAsyncTask *)async_task)->body.queue, arr);
-        });
+        }
     }
 }
 
@@ -227,9 +227,9 @@ static MVMAsyncTask * read_bytes(MVMThreadContext *tc, MVMOSHandle *h, MVMObject
     }
 
     /* Create async task handle. */
-    MVMROOT4(tc, queue, schedulee, h, buf_type, {
+    MVMROOT4(tc, queue, schedulee, h, buf_type) {
         task = (MVMAsyncTask *)MVM_repr_alloc_init(tc, async_type);
-    });
+    }
     MVM_ASSIGN_REF(tc, &(task->common.header), task->body.queue, queue);
     MVM_ASSIGN_REF(tc, &(task->common.header), task->body.schedulee, schedulee);
     task->body.ops  = &read_op_table;
@@ -239,9 +239,9 @@ static MVMAsyncTask * read_bytes(MVMThreadContext *tc, MVMOSHandle *h, MVMObject
     task->body.data = ri;
 
     /* Hand the task off to the event loop. */
-    MVMROOT(tc, task, {
+    MVMROOT(tc, task) {
         MVM_io_eventloop_queue_work(tc, (MVMObject *)task);
-    });
+    }
 
     return task;
 }
@@ -265,23 +265,23 @@ static void on_write(uv_udp_send_t *req, int status) {
     MVMAsyncTask     *t   = MVM_io_eventloop_get_active_work(tc, wi->work_idx);
     MVM_repr_push_o(tc, arr, t->body.schedulee);
     if (status >= 0) {
-        MVMROOT2(tc, arr, t, {
+        MVMROOT2(tc, arr, t) {
             MVMObject *bytes_box = MVM_repr_box_int(tc,
                 tc->instance->boot_types.BOOTInt,
                 wi->buf.len);
             MVM_repr_push_o(tc, arr, bytes_box);
-        });
+        }
         MVM_repr_push_o(tc, arr, tc->instance->boot_types.BOOTStr);
     }
     else {
         MVM_repr_push_o(tc, arr, tc->instance->boot_types.BOOTInt);
-        MVMROOT2(tc, arr, t, {
+        MVMROOT2(tc, arr, t) {
             MVMString *msg_str = MVM_string_ascii_decode_nt(tc,
                 tc->instance->VMString, uv_strerror(status));
             MVMObject *msg_box = MVM_repr_box_str(tc,
                 tc->instance->boot_types.BOOTStr, msg_str);
             MVM_repr_push_o(tc, arr, msg_box);
-        });
+        }
     }
     MVM_repr_push_o(tc, t->body.queue, arr);
     MVM_free(wi->req);
@@ -318,19 +318,19 @@ static void write_setup(MVMThreadContext *tc, uv_loop_t *loop, MVMObject *async_
 
     if ((r = uv_udp_send(wi->req, handle_data->handle, &(wi->buf), 1, wi->dest_addr, on_write)) < 0) {
         /* Error; need to notify. */
-        MVMROOT(tc, async_task, {
+        MVMROOT(tc, async_task) {
             MVMObject    *arr = MVM_repr_alloc_init(tc, tc->instance->boot_types.BOOTArray);
             MVM_repr_push_o(tc, arr, ((MVMAsyncTask *)async_task)->body.schedulee);
             MVM_repr_push_o(tc, arr, tc->instance->boot_types.BOOTInt);
-            MVMROOT(tc, arr, {
+            MVMROOT(tc, arr) {
                 MVMString *msg_str = MVM_string_ascii_decode_nt(tc,
                     tc->instance->VMString, uv_strerror(r));
                 MVMObject *msg_box = MVM_repr_box_str(tc,
                     tc->instance->boot_types.BOOTStr, msg_str);
                 MVM_repr_push_o(tc, arr, msg_box);
-            });
+            }
             MVM_repr_push_o(tc, ((MVMAsyncTask *)async_task)->body.queue, arr);
-        });
+        }
 
         /* Cleanup handle. */
         MVM_free_null(wi->req);
@@ -385,12 +385,12 @@ static MVMAsyncTask * write_bytes_to(MVMThreadContext *tc, MVMOSHandle *h, MVMOb
         MVM_exception_throw_adhoc(tc, "asyncwritebytesto requires a native array of uint8 or int8");
 
     /* Resolve destination and create async task handle. */
-    MVMROOT4(tc, queue, schedulee, h, buffer, {
-        MVMROOT(tc, async_type, {
+    MVMROOT4(tc, queue, schedulee, h, buffer) {
+        MVMROOT(tc, async_type) {
             dest_addr = MVM_io_resolve_host_name(tc, host, port, MVM_SOCKET_FAMILY_UNSPEC, MVM_SOCKET_TYPE_DGRAM, MVM_SOCKET_PROTOCOL_ANY, 0);
-        });
+        }
         task = (MVMAsyncTask *)MVM_repr_alloc_init(tc, async_type);
-    });
+    }
     MVM_ASSIGN_REF(tc, &(task->common.header), task->body.queue, queue);
     MVM_ASSIGN_REF(tc, &(task->common.header), task->body.schedulee, schedulee);
     task->body.ops  = &write_op_table;
@@ -401,9 +401,9 @@ static MVMAsyncTask * write_bytes_to(MVMThreadContext *tc, MVMOSHandle *h, MVMOb
     task->body.data = wi;
 
     /* Hand the task off to the event loop. */
-    MVMROOT(tc, task, {
+    MVMROOT(tc, task) {
         MVM_io_eventloop_queue_work(tc, (MVMObject *)task);
-    });
+    }
 
     return task;
 }
@@ -431,10 +431,10 @@ static MVMint64 close_socket(MVMThreadContext *tc, MVMOSHandle *h) {
     MVMIOAsyncUDPSocketData *data = (MVMIOAsyncUDPSocketData *)h->body.data;
     MVMAsyncTask *task;
 
-    MVMROOT(tc, h, {
+    MVMROOT(tc, h) {
         task = (MVMAsyncTask *)MVM_repr_alloc_init(tc,
             tc->instance->boot_types.BOOTAsync);
-    });
+    }
     task->body.ops  = &close_op_table;
     task->body.data = data->handle;
     MVM_io_eventloop_queue_work(tc, (MVMObject *)task);
@@ -505,38 +505,38 @@ static void setup_setup(MVMThreadContext *tc, uv_loop_t *loop, MVMObject *async_
         /* UDP handle initialized; wrap it up in an I/O handle and send. */
         MVMAsyncTask *t   = (MVMAsyncTask *)async_task;
         MVMObject    *arr;
-        MVMROOT(tc, t, {
+        MVMROOT(tc, t) {
             arr = MVM_repr_alloc_init(tc, tc->instance->boot_types.BOOTArray);
             MVM_repr_push_o(tc, arr, t->body.schedulee);
-            MVMROOT(tc, arr, {
+            MVMROOT(tc, arr) {
                 MVMOSHandle          *result = (MVMOSHandle *)MVM_repr_alloc_init(tc, tc->instance->boot_types.BOOTIO);
                 MVMIOAsyncUDPSocketData *data   = MVM_calloc(1, sizeof(MVMIOAsyncUDPSocketData));
                 data->handle                 = udp_handle;
                 result->body.ops             = &op_table;
                 result->body.data            = data;
                 MVM_repr_push_o(tc, arr, (MVMObject *)result);
-            });
+            }
             MVM_repr_push_o(tc, arr, tc->instance->boot_types.BOOTStr);
-        });
+        }
         MVM_repr_push_o(tc, t->body.queue, arr);
     }
     else {
         /* Something failed; need to notify. */
-        MVMROOT(tc, async_task, {
+        MVMROOT(tc, async_task) {
             MVMObject    *arr = MVM_repr_alloc_init(tc, tc->instance->boot_types.BOOTArray);
             MVMAsyncTask *t   = (MVMAsyncTask *)async_task;
             MVM_repr_push_o(tc, arr, t->body.schedulee);
             MVM_repr_push_o(tc, arr, tc->instance->boot_types.BOOTIO);
-            MVMROOT2(tc, arr, t, {
+            MVMROOT2(tc, arr, t) {
                 MVMString *msg_str = MVM_string_ascii_decode_nt(tc,
                     tc->instance->VMString, uv_strerror(r));
                 MVMObject *msg_box = MVM_repr_box_str(tc,
                     tc->instance->boot_types.BOOTStr, msg_str);
                 MVM_repr_push_o(tc, arr, msg_box);
-            });
+            }
             MVM_repr_push_o(tc, t->body.queue, arr);
             uv_close((uv_handle_t *)udp_handle, free_on_close_cb);
-        });
+        }
     }
 }
 
@@ -578,15 +578,15 @@ MVMObject * MVM_io_socket_udp_async(MVMThreadContext *tc, MVMObject *queue,
 
     /* Resolve hostname. (Could be done asynchronously too.) */
     if (host && IS_CONCRETE(host)) {
-        MVMROOT3(tc, queue, schedulee, async_type, {
+        MVMROOT3(tc, queue, schedulee, async_type) {
             bind_addr = MVM_io_resolve_host_name(tc, host, port, MVM_SOCKET_FAMILY_UNSPEC, MVM_SOCKET_TYPE_DGRAM, MVM_SOCKET_PROTOCOL_ANY, 1);
-        });
+        }
     }
 
     /* Create async task handle. */
-    MVMROOT2(tc, queue, schedulee, {
+    MVMROOT2(tc, queue, schedulee) {
         task = (MVMAsyncTask *)MVM_repr_alloc_init(tc, async_type);
-    });
+    }
     MVM_ASSIGN_REF(tc, &(task->common.header), task->body.queue, queue);
     MVM_ASSIGN_REF(tc, &(task->common.header), task->body.schedulee, schedulee);
     task->body.ops  = &setup_op_table;
@@ -596,9 +596,9 @@ MVMObject * MVM_io_socket_udp_async(MVMThreadContext *tc, MVMObject *queue,
     task->body.data = ssi;
 
     /* Hand the task off to the event loop. */
-    MVMROOT(tc, task, {
+    MVMROOT(tc, task) {
         MVM_io_eventloop_queue_work(tc, (MVMObject *)task);
-    });
+    }
 
     return (MVMObject *)task;
 }
