@@ -8,6 +8,10 @@ void MVM_spesh_debug_printf(MVMThreadContext *tc, const char *format, ...) {
     va_end(list);
 }
 
+size_t MVM_spesh_debug_tell(MVMThreadContext *tc) {
+    return ftell(tc->instance->spesh_log_fh);
+}
+
 void MVM_spesh_debug_flush(MVMThreadContext *tc) {
     fflush(tc->instance->spesh_log_fh);
 }
