@@ -220,6 +220,7 @@ static void apply_transform(MVMThreadContext *tc, MVMSpeshGraph *g, GraphState *
                         ins->info = MVM_op_get_op(MVM_OP_null);
                         break;
                     case MVM_OP_sp_p6oget_i:
+                    case MVM_OP_sp_p6oget_u:
                         ins->info = MVM_op_get_op(MVM_OP_const_i64_16);
                         ins->operands[1].lit_i16 = 0;
                         break;
@@ -488,14 +489,13 @@ static void add_deopt_materializations_ins(MVMThreadContext *tc, MVMSpeshGraph *
     }
 }
 
-/* Performs the analysis phase of partial escape anslysis, figuring out what
+/* Performs the analysis phase of partial escape analysis, figuring out what
  * rewrites we can do on the graph to achieve scalar replacement of objects
  * and, perhaps, some guard eliminations. */
 static MVMuint32 analyze(MVMThreadContext *tc, MVMSpeshGraph *g, GraphState *gs) {
     MVMSpeshBB **rpo = MVM_spesh_graph_reverse_postorder(tc, g);
     MVMuint8 *seen = MVM_calloc(g->num_bbs, 1);
     MVMuint32 found_replaceable = 0;
-    MVMuint32 ins_count = 0;
     MVMuint32 i;
     for (i = 0; i < g->num_bbs; i++) {
         MVMSpeshBB *bb = rpo[i];
@@ -583,11 +583,13 @@ static MVMuint32 analyze(MVMThreadContext *tc, MVMSpeshGraph *g, GraphState *gs)
                     break;
                 }
                 case MVM_OP_sp_bind_i64:
+                case MVM_OP_sp_bind_u64:
                 case MVM_OP_sp_bind_n:
                 case MVM_OP_sp_bind_s:
                 case MVM_OP_sp_bind_s_nowb:
                 case MVM_OP_sp_bind_o:
                 case MVM_OP_sp_p6obind_i:
+                case MVM_OP_sp_p6obind_u:
                 case MVM_OP_sp_p6obind_n:
                 case MVM_OP_sp_p6obind_s:
                 case MVM_OP_sp_p6obind_o: {
@@ -597,6 +599,7 @@ static MVMuint32 analyze(MVMThreadContext *tc, MVMSpeshGraph *g, GraphState *gs)
                     MVMSpeshPEAAllocation *alloc = target->pea.allocation;
                     if (allocation_tracked(alloc)) {
                         MVMint32 is_p6o_op = opcode == MVM_OP_sp_p6obind_i ||
+                            opcode == MVM_OP_sp_p6obind_u ||
                             opcode == MVM_OP_sp_p6obind_n ||
                             opcode == MVM_OP_sp_p6obind_s ||
                             opcode == MVM_OP_sp_p6obind_o;
@@ -627,6 +630,7 @@ static MVMuint32 analyze(MVMThreadContext *tc, MVMSpeshGraph *g, GraphState *gs)
                     break;
                 }
                 case MVM_OP_sp_p6oget_i:
+                case MVM_OP_sp_p6oget_u:
                 case MVM_OP_sp_p6oget_n:
                 case MVM_OP_sp_p6oget_s:
                 case MVM_OP_sp_p6oget_o:
@@ -699,7 +703,6 @@ static MVMuint32 analyze(MVMThreadContext *tc, MVMSpeshGraph *g, GraphState *gs)
             }
 
             ins = ins->next;
-            ins_count++;
         }
 
         seen[bb->rpo_idx] = 1;
