@@ -4,9 +4,15 @@
  * a result of the specified type. The type must have the MVMString REPR. */
 MVMString * MVM_string_ascii_decode(MVMThreadContext *tc, const MVMObject *result_type, const char *ascii, size_t bytes) {
     MVMString *result;
-    MVMGrapheme32 *buffer = MVM_malloc(sizeof(MVMGrapheme32) * bytes);
+    MVMGrapheme32 *buffer;
     size_t i, result_graphs;
 
+    if (bytes == 0 && tc->instance->str_consts.empty) {
+        return tc->instance->str_consts.empty;
+    }
+
+    buffer = MVM_malloc(sizeof(MVMGrapheme32) * bytes);
+
     result_graphs = 0;
     for (i = 0; i < bytes; i++) {
         if (ascii[i] == '\r' && i + 1 < bytes && ascii[i + 1] == '\n') {
@@ -213,3 +219,42 @@ char * MVM_string_ascii_encode(MVMThreadContext *tc, MVMString *str, MVMuint64 *
 char * MVM_string_ascii_encode_any(MVMThreadContext *tc, MVMString *str) {
     return MVM_string_ascii_encode(tc, str, NULL, 0);
 }
+
+/* Encodes the specified string to ASCII using libc malloc.  */
+char * MVM_string_ascii_encode_malloc(MVMThreadContext *tc, MVMString *str) {
+    /* ASCII is a single byte encoding, but \r\n is a 2-byte grapheme, so we
+     * may have to resize as we go. */
+    MVMuint32      lengthu   = MVM_string_graphs(tc, str);
+
+    size_t         result_alloc = lengthu;
+    MVMuint8      *result = malloc(result_alloc + 1);
+    if (str->body.storage_type == MVM_STRING_GRAPHEME_ASCII) {
+        /* No encoding needed; directly copy. */
+        memcpy(result, str->body.storage.blob_ascii, lengthu);
+        result[lengthu] = 0;
+    }
+    else {
+        MVMuint32 i = 0;
+        MVMCodepointIter ci;
+        MVM_string_ci_init(tc, &ci, str, 0, 0);
+        while (MVM_string_ci_has_more(tc, &ci)) {
+            MVMCodepoint ord = MVM_string_ci_get_codepoint(tc, &ci);
+            if (i == result_alloc) {
+                result_alloc += 8;
+                result = realloc(result, result_alloc + 1);
+            }
+            if (0 <= ord && ord <= 127) {
+                result[i++] = (MVMuint8)ord;
+            }
+            else {
+                free(result);
+                MVM_exception_throw_adhoc(tc,
+                    "Error encoding ASCII string: could not encode codepoint %d",
+                    ord);
+            }
+        }
+        result[i] = 0;
+    }
+
+    return (char *)result;
+}
