@@ -1868,7 +1868,8 @@ sub UnicodeData {
              || $point->{name} eq '<CJK Ideograph Extension D>'
              || $point->{name} eq '<CJK Ideograph Extension E>'
              || $point->{name} eq '<CJK Ideograph Extension F>'
-             || $point->{name} eq '<CJK Ideograph Extension G>')
+             || $point->{name} eq '<CJK Ideograph Extension G>'
+             || $point->{name} eq '<CJK Ideograph Extension H>')
             {
                 $point->{name} = '<CJK UNIFIED IDEOGRAPH>'
             }
